==> api-0.16.0-sources.jar: io/strimzi/api/kafka/model/KafkaConnectorFluent.java <==
package io.strimzi.api.kafka.model;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.strimzi.api.kafka.model.status.KafkaConnectorStatusFluent;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import io.strimzi.api.kafka.model.status.KafkaConnectorStatus;
import io.strimzi.api.kafka.model.status.KafkaConnectorStatusBuilder;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface KafkaConnectorFluent<A extends KafkaConnectorFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public KafkaConnectorSpec getSpec();
    public KafkaConnectorSpec buildSpec();
    public A withSpec(KafkaConnectorSpec spec);
    public Boolean hasSpec();
    public KafkaConnectorFluent.SpecNested<A> withNewSpec();
    public KafkaConnectorFluent.SpecNested<A> withNewSpecLike(KafkaConnectorSpec item);
    public KafkaConnectorFluent.SpecNested<A> editSpec();
    public KafkaConnectorFluent.SpecNested<A> editOrNewSpec();
    public KafkaConnectorFluent.SpecNested<A> editOrNewSpecLike(KafkaConnectorSpec item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public KafkaConnectorStatus getStatus();
    public KafkaConnectorStatus buildStatus();
    public A withStatus(KafkaConnectorStatus status);
    public Boolean hasStatus();
    public KafkaConnectorFluent.StatusNested<A> withNewStatus();
    public KafkaConnectorFluent.StatusNested<A> withNewStatusLike(KafkaConnectorStatus item);
    public KafkaConnectorFluent.StatusNested<A> editStatus();
    public KafkaConnectorFluent.StatusNested<A> editOrNewStatus();
    public KafkaConnectorFluent.StatusNested<A> editOrNewStatusLike(KafkaConnectorStatus item);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public KafkaConnectorFluent.MetadataNested<A> withNewMetadata();
    public KafkaConnectorFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public KafkaConnectorFluent.MetadataNested<A> editMetadata();
    public KafkaConnectorFluent.MetadataNested<A> editOrNewMetadata();
    public KafkaConnectorFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);

    public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaConnectorSpecFluent<KafkaConnectorFluent.SpecNested<N>>{

        
    public N and();    public N endSpec();
}
    public interface StatusNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaConnectorStatusFluent<KafkaConnectorFluent.StatusNested<N>>{

        
    public N and();    public N endStatus();
}
    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<KafkaConnectorFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}

==> api-0.23.0-sources.jar: io/strimzi/api/kafka/model/KafkaConnectorFluent.java <==
package io.strimzi.api.kafka.model;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.strimzi.api.kafka.model.status.KafkaConnectorStatusFluent;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import io.strimzi.api.kafka.model.status.KafkaConnectorStatus;
import io.strimzi.api.kafka.model.status.KafkaConnectorStatusBuilder;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface KafkaConnectorFluent<A extends KafkaConnectorFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public KafkaConnectorSpec getSpec();
    public KafkaConnectorSpec buildSpec();
    public A withSpec(KafkaConnectorSpec spec);
    public Boolean hasSpec();
    public KafkaConnectorFluent.SpecNested<A> withNewSpec();
    public KafkaConnectorFluent.SpecNested<A> withNewSpecLike(KafkaConnectorSpec item);
    public KafkaConnectorFluent.SpecNested<A> editSpec();
    public KafkaConnectorFluent.SpecNested<A> editOrNewSpec();
    public KafkaConnectorFluent.SpecNested<A> editOrNewSpecLike(KafkaConnectorSpec item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public KafkaConnectorStatus getStatus();
    public KafkaConnectorStatus buildStatus();
    public A withStatus(KafkaConnectorStatus status);
    public Boolean hasStatus();
    public KafkaConnectorFluent.StatusNested<A> withNewStatus();
    public KafkaConnectorFluent.StatusNested<A> withNewStatusLike(KafkaConnectorStatus item);
    public KafkaConnectorFluent.StatusNested<A> editStatus();
    public KafkaConnectorFluent.StatusNested<A> editOrNewStatus();
    public KafkaConnectorFluent.StatusNested<A> editOrNewStatusLike(KafkaConnectorStatus item);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public KafkaConnectorFluent.MetadataNested<A> withNewMetadata();
    public KafkaConnectorFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public KafkaConnectorFluent.MetadataNested<A> editMetadata();
    public KafkaConnectorFluent.MetadataNested<A> editOrNewMetadata();
    public KafkaConnectorFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(int[] arg1,int arg2,int arg3);
    public A withNewApiVersion(char[] arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A withNewApiVersion(byte[] arg1,int arg2);
    public A withNewApiVersion(byte[] arg1);
    public A withNewApiVersion(char[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiVersion(String arg1);
    public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaConnectorSpecFluent<KafkaConnectorFluent.SpecNested<N>> {

            public N and();
            public N endSpec();    }


    public interface StatusNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaConnectorStatusFluent<KafkaConnectorFluent.StatusNested<N>> {

            public N and();
            public N endStatus();    }


    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<KafkaConnectorFluent.MetadataNested<N>> {

            public N and();
            public N endMetadata();    }


}
